@@ -1,41 +1,41 @@
 import getpass
-TDlcH=object
-TDlch=staticmethod
-TDlck=False
-TDlcd=Exception
-TDlcm=None
-TDlce=input
-TDlcn=list
+hbufN=object
+hbufR=staticmethod
+hbufV=False
+hbufU=Exception
+hbufI=None
+hbufx=input
+hbufm=list
 import json
 import logging
 import sys
-from localstack.config import CONFIG_FILE_PATH,load_config_file
+from localstack.config import load_config_file,save_config_file
 from localstack.constants import API_ENDPOINT
-from localstack.utils.common import load_file,safe_requests,save_file,to_str
+from localstack.utils.common import safe_requests,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(TDlcH):
- @TDlch
+class AuthProvider(hbufN):
+ @hbufR
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @TDlch
+ @hbufR
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @TDlch
- def get(provider,raise_error=TDlck):
+ @hbufR
+ def get(provider,raise_error=hbufV):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise TDlcd(msg)
-   return TDlcm
+    raise hbufU(msg)
+   return hbufI
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @TDlch
+ @hbufR
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,35 +46,35 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except TDlcd:
+  except hbufU:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=TDlce()
+   username=hbufx()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise TDlcd("Not implemented")
-def login(provider,username=TDlcm):
+  raise hbufU("Not implemented")
+def login(provider,username=hbufI):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=TDlcn(AuthProvider.providers().keys())
-  raise TDlcd('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=hbufm(AuthProvider.providers().keys())
+  raise hbufU('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise TDlcd("Unable to verify login credentials - please try again")
+  raise hbufU("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
- save_file(CONFIG_FILE_PATH,json.dumps(configs))
+ save_config_file(configs)
 def logout():
- configs=json_loads(load_file(CONFIG_FILE_PATH,default="{}"))
+ configs=load_config_file()
  configs["login"]={}
- save_file(CONFIG_FILE_PATH,json.dumps(configs))
+ save_config_file(configs)
 def json_loads(s):
  return json.loads(to_str(s))
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
