@@ -1,16 +1,16 @@
 import logging
-RybEs=True
-RybEk=False
-RybEw=None
-RybEt=Exception
-RybEM=open
-RybEh=bool
-RybEc=str
-RybEr=int
-RybEd=dict
-RybET=list
-RybEV=isinstance
-RybEv=super
+rBEvz=True
+rBEvy=False
+rBEvi=None
+rBEvh=Exception
+rBEvS=open
+rBEvR=bool
+rBEvw=str
+rBEvp=int
+rBEve=dict
+rBEvG=list
+rBEvf=isinstance
+rBEvc=super
 import os
 import sys
 from typing import Any,Callable,Dict,List
@@ -20,10 +20,10 @@ class ProCliPlugin(LocalstackCliPlugin):
  name="pro"
  def should_load(self):
   e=os.getenv("LOCALSTACK_API_KEY")
-  return RybEs if e else RybEk
+  return rBEvz if e else rBEvy
  def is_active(self):
   return self.should_load()
- def attach(self,cli:LocalstackCli)->RybEw:
+ def attach(self,cli:LocalstackCli)->rBEvi:
   group:click.Group=cli.group
   group.add_command(cmd_login)
   group.add_command(cmd_logout)
@@ -42,7 +42,7 @@ def cmd_login(username,provider):
  try:
   auth.login(provider,username)
   console.print("successfully logged in")
- except RybEt as e:
+ except rBEvh as e:
   console.print("authentication error: %s"%e)
 @click.command(name="logout",help="Log out and delete any session tokens")
 def cmd_logout():
@@ -50,7 +50,7 @@ def cmd_logout():
  try:
   auth.logout()
   console.print("successfully logged out")
- except RybEt as e:
+ except rBEvh as e:
   console.print("logout error: %s"%e)
 @daemons.command(name="start",help="Start local daemon processes")
 def cmd_daemons_start():
@@ -69,7 +69,7 @@ def cmd_daemons_log():
  if not os.path.isfile(file_path):
   console.print("no log found")
  else:
-  with RybEM(file_path,"r")as fd:
+  with rBEvS(file_path,"r")as fd:
    for line in fd:
     sys.stdout.write(line)
     sys.stdout.flush()
@@ -77,99 +77,161 @@ def cmd_daemons_log():
 def dns():
  pass
 @dns.command(name="systemd-resolved",help="Manage DNS settings of systemd-resolved (Ubuntu, Debian etc.)")
-@click.option("--revert",is_flag=RybEs,help="Revert systemd-resolved settings for the docker interface")
-def cmd_dns_systemd(revert:RybEh):
+@click.option("--revert",is_flag=rBEvz,help="Revert systemd-resolved settings for the docker interface")
+def cmd_dns_systemd(revert:rBEvR):
  import localstack_ext.services.dns_server
  from localstack_ext.bootstrap.dns_utils import configure_systemd
  console.print("Configuring systemd-resolved...")
  logger_name=localstack_ext.services.dns_server.LOG.name
  localstack_ext.services.dns_server.LOG=ConsoleLogger(logger_name)
  configure_systemd(revert)
-def _cpvcs_initialized(pod_name:RybEc)->RybEh:
+def _cpvcs_initialized(pod_name:rBEvw)->rBEvR:
  from localstack_ext.bootstrap.cpvcs.utils.common import config_context
  config_context.set_pod_context(pod_name=pod_name)
  if not config_context.is_initialized():
   console.print("[red]Error:[/red] Could not find local CPVCS instance")
-  return RybEk
- return RybEs
+  return rBEvy
+ return rBEvz
 @click.group(name="cpvcs",help="Experimental Cloud Pods with elaborate versioning mechanism")
 def cpvcs():
- pass
+ from localstack_ext.bootstrap.licensing import is_logged_in
+ if not is_logged_in():
+  console.print("[red]Error:[/red] not logged in, please log in first")
+  sys.exit(1)
 @cpvcs.command(name="init",help="Creates a new cloud pod with cpvcs enabled")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_init(name:RybEc):
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_init(name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  from localstack_ext.bootstrap.cpvcs.utils.common import config_context
+ config_context.set_pod_context(name)
  if config_context.is_initialized():
   console.print(f"[red]Error:[/red] CPVCS already instanciated for pod {name}")
  else:
   pods_client.init_cpvcs(pod_name=name,pre_config={"backend":"cpvcs"})
   console.print("Successfully created local CPVCS instance!")
+@cpvcs.command(name="delete",help="Deletes the specified cloud pod. By default only locally")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+@click.option("-r","--remote",help="Whether the Pod should also be deleted remotely.",is_flag=rBEvz,default=rBEvy)
+def cmd_cpvcs_delete(name:rBEvw,remote:rBEvR):
+ from localstack_ext.bootstrap import pods_client
+ result=pods_client.delete_pod(pod_name=name,remote=remote,pre_config={"backend":"cpvcs"})
+ if result:
+  console.print(f"Successfully deleted {name}")
+ else:
+  console.print(f"[yellow]{name} not available locally[/yellow]")
+@cpvcs.command(name="register",help="Registers a local cloudpod instance with platform")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_register_remote(name:rBEvw):
+ from localstack_ext.bootstrap import pods_client
+ if _cpvcs_initialized(pod_name=name):
+  result=pods_client.register_remote(pod_name=name,pre_config={"backend":"cpvcs"})
+  if result:
+   console.print(f"Successfully registred {name} with remote!")
+  else:
+   console.print(f"[red]Error:[/red] Pod with name {name} is already registered")
+@cpvcs.command(name="rename",help="Renames the pod. If the pod is remotely registered, change is also propagated to remote")
+@click.option("-n","--name",help="Current Name of the cloud pod",required=rBEvz)
+@click.option("-nn","--new-name",help="New name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_rename(name:rBEvw,new_name:rBEvw):
+ from localstack_ext.bootstrap import pods_client
+ if _cpvcs_initialized(pod_name=name):
+  result=pods_client.rename_pod(current_pod_name=name,new_pod_name=new_name,pre_config={"backend":"cpvcs"})
+  if result:
+   console.print(f"Successfully renamed {name} to {new_name}")
+  else:
+   console.print(f"[red]Error:[/red] Failed to rename {name} to {new_name}")
 @cpvcs.command(name="commit",help="Commits the current expansion point and creates a new (empty) revision")
 @click.option("-m","--message",help="Add a comment describing the revision")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_commit(message:RybEc,name:RybEc):
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_commit(message:rBEvw,name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  if _cpvcs_initialized(pod_name=name):
   pods_client.commit_state(pod_name=name,pre_config={"backend":"cpvcs"},message=message)
   console.print("Successfully commited the current state")
 @cpvcs.command(name="push",help="Creates a new version by using the state files in the current expansion point (latest commit)")
-@click.option("--squash",is_flag=RybEs,help="Squashes commits together, so only the latest commit is stored in the revision graph")
+@click.option("--squash",is_flag=rBEvz,help="Squashes commits together, so only the latest commit is stored in the revision graph")
 @click.option("-m","--message",help="Add a comment describing the version")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_push(squash:RybEh,message:RybEc,name:RybEc):
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_push(squash:rBEvR,message:rBEvw,name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  if _cpvcs_initialized(pod_name=name):
   pods_client.push_state(pod_name=name,pre_config={"backend":"cpvcs"},squash_commits=squash,comment=message)
   console.print("Successfully pushed the current state")
 @cpvcs.command(name="inject",help="Injects the state from a version into the application runtime")
-@click.option("--version",default="-1",type=RybEr,help="Loads the state of the specified version - Most recent one by default")
-@click.option("--reset",is_flag=RybEs,default=RybEk,help="Will reset the application state before injecting")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_inject(version:RybEr,reset:RybEh,name:RybEc):
+@click.option("-v","--version",default="-1",type=rBEvp,help="Loads the state of the specified version - Most recent one by default")
+@click.option("--reset",is_flag=rBEvz,default=rBEvy,help="Will reset the application state before injecting")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_inject(version:rBEvp,reset:rBEvR,name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  if _cpvcs_initialized(pod_name=name):
   pods_client.inject_state(pod_name=name,version=version,reset_state=reset,pre_config={"backend":"cpvcs"})
+@click.option("--inject/--no-inject",default=rBEvz,help="Whether the latest version of the pulled pod should be injected")
+@click.option("--reset/--no-reset",default=rBEvz,help="Whether the current application state should be reset after the pod has been pulled")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+@cpvcs.command(name="pull",help="Injects the state from a version into the application runtime")
+def cmd_cpvcs_pull(name:rBEvw,inject:rBEvR,reset:rBEvR):
+ from localstack_ext.bootstrap import pods_client
+ pods_client.pull_state(pod_name=name,inject_version_state=inject,reset_state_before=reset,pre_config={"backend":"cpvcs"})
+@cpvcs.command(name="list-pods",help="Lists all pods and indicates which pods exist locally and, by default, which ones are managed remotely")
+@click.option("--remote","-r",is_flag=rBEvz,default=rBEvy)
+def cmd_cpvcs_list_pods(remote:rBEvR):
+ from localstack_ext.bootstrap import pods_client
+ pods=pods_client.list_pods_cpvcs(remote=remote,pre_config={"backend":"cpvcs"})
+ if not pods:
+  console.print(f"[yellow]No pods available {'locally' if not remote else ''}[/yellow]")
+ else:
+  console.print("\n".join(pods))
 @cpvcs.command(name="versions",help="Lists all available version numbers")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_versions(name:RybEc):
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_versions(name:rBEvw):
  if _cpvcs_initialized(pod_name=name):
   from localstack_ext.bootstrap import pods_client
   version_list=pods_client.list_versions(pod_name=name,pre_config={"backend":"cpvcs"})
   result="\n".join(version_list)
   console.print(result)
 @cpvcs.command(name="version-info")
-@click.option("--version",required=RybEs,type=RybEr)
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_version_info(version:RybEr,name:RybEc):
+@click.option("-v","--version",required=rBEvz,type=rBEvp)
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_version_info(version:rBEvp,name:rBEvw):
  if _cpvcs_initialized(pod_name=name):
   from localstack_ext.bootstrap import pods_client
   info=pods_client.get_version_info(version=version,pod_name=name,pre_config={"backend":"cpvcs"})
-  console.print(info)
+  console.print_json(info)
+@cpvcs.command(name="metamodel",help="Displays the content metamodel as json")
+@click.option("-v","--version",type=rBEvp,default=-1,help="Latest version by default")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_version_metamodel(version:rBEvp,name:rBEvw):
+ if _cpvcs_initialized(pod_name=name):
+  from localstack_ext.bootstrap import pods_client
+  metamodel=pods_client.get_version_metamodel(version=version,pod_name=name,pre_config={"backend":"cpvcs"})
+  if metamodel:
+   console.print_json(metamodel)
+  else:
+   console.print(f"[red]Could not find metaodel for pod {name} with version {version}[/red]")
 @cpvcs.command(name="set-version",help="Set HEAD to a specific version")
-@click.option("--version",required=RybEs,type=RybEr,help="The version the state should be set to")
-@click.option("--inject",is_flag=RybEs,help="Whether the state should be directly injected into the application runtime after changing version")
-@click.option("--reset/--no-reset",default=RybEs,help="Whether the current application state should be reset before changing version")
-@click.option("--commit-before",is_flag=RybEs,help="Whether the current application state should be commited to the currently selected version before changing version")
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_set_version(version:RybEr,inject:RybEh,reset:RybEh,commit_before:RybEh,name:RybEc):
+@click.option("-v","--version",required=rBEvz,type=rBEvp,help="The version the state should be set to")
+@click.option("--inject/--no-inject",default=rBEvz,help="Whether the state should be directly injected into the application runtime after changing version")
+@click.option("--reset/--no-reset",default=rBEvz,help="Whether the current application state should be reset before changing version")
+@click.option("--commit-before",is_flag=rBEvy,help="Whether the current application state should be commited to the currently selected version before changing version")
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_set_version(version:rBEvp,inject:rBEvR,reset:rBEvR,commit_before:rBEvR,name:rBEvw):
  if _cpvcs_initialized(pod_name=name):
   from localstack_ext.bootstrap import pods_client
   pods_client.set_version(version=version,inject_version_state=inject,reset_state=reset,commit_before=commit_before,pod_name=name,pre_config={"backend":"cpvcs"})
 @cpvcs.command(name="commits",help="Shows the commit history of a version")
 @click.option("--version","-v",default=-1)
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_commits(version:RybEr,name:RybEc):
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_commits(version:rBEvp,name:rBEvw):
  if _cpvcs_initialized(pod_name=name):
   from localstack_ext.bootstrap import pods_client
   commits=pods_client.list_version_commits(version=version,pod_name=name,pre_config={"backend":"cpvcs"})
   result="\n".join(commits)
   console.print(result)
 @cpvcs.command(name="commit-diff",help="Shows the changes made by a commit")
-@click.option("--version","-v",required=RybEs)
-@click.option("--commit","-c",required=RybEs)
-@click.option("-n","--name",help="Name of the cloud pod",required=RybEs)
-def cmd_cpvcs_commit_diff(version:RybEr,commit:RybEr,name:RybEc):
+@click.option("--version","-v",required=rBEvz)
+@click.option("--commit","-c",required=rBEvz)
+@click.option("-n","--name",help="Name of the cloud pod",required=rBEvz)
+def cmd_cpvcs_commit_diff(version:rBEvp,commit:rBEvp,name:rBEvw):
  if _cpvcs_initialized(pod_name=name):
   from localstack_ext.bootstrap import pods_client
   commit_diff=pods_client.get_commit_diff(version=version,commit=commit,pod_name=name,pre_config={"backend":"cpvcs"})
@@ -191,11 +253,11 @@ def cmd_pod_list():
  from localstack.utils.common import format_bytes
  from localstack_ext.bootstrap import pods_client
  try:
-  result=pods_client.list_pods(RybEw)
+  result=pods_client.list_pods(rBEvi)
   status.stop()
   columns={"pod_name":"Name","backend":"Backend","url":"URL","size":"Size","state":"State"}
   print_table(columns,result,formatters={"size":format_bytes})
- except RybEt as e:
+ except rBEvh as e:
   status.stop()
   if config.DEBUG:
    console.print_exception()
@@ -207,48 +269,48 @@ def cmd_pod_create():
  console.print(msg)
 @pod.command(name="push",help="Push the state of the LocalStack instance to a cloud pod")
 @click.argument("name")
-def cmd_pod_push(name:RybEc):
+def cmd_pod_push(name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  pods_client.push_state(name)
 @pod.command(name="pull",help="Pull the state of a cloud pod into the running LocalStack instance")
 @click.argument("name")
-def cmd_pod_pull(name:RybEc):
+def cmd_pod_pull(name:rBEvw):
  from localstack_ext.bootstrap import pods_client
  pods_client.pull_state(name)
 @pod.command(name="reset",help="Reset the local state to get a fresh LocalStack instance")
 def cmd_pod_reset():
  from localstack_ext.bootstrap import pods_client
  pods_client.reset_local_state()
-def print_table(columns:Dict[RybEc,RybEc],rows:List[Dict[RybEc,Any]],formatters:Dict[RybEc,Callable[[Any],RybEc]]=RybEw):
+def print_table(columns:Dict[rBEvw,rBEvw],rows:List[Dict[rBEvw,Any]],formatters:Dict[rBEvw,Callable[[Any],rBEvw]]=rBEvi):
  from rich.table import Table
- if formatters is RybEw:
-  formatters=RybEd()
+ if formatters is rBEvi:
+  formatters=rBEve()
  t=Table()
  for k,name in columns.items():
   t.add_column(name)
  for row in rows:
-  cells=RybET()
+  cells=rBEvG()
   for c in columns.keys():
    cell=row.get(c)
    if c in formatters:
     cell=formatters[c](cell)
-   if cell is RybEw:
+   if cell is rBEvi:
     cell=""
-   if not RybEV(cell,RybEc):
-    cell=RybEc(cell)
+   if not rBEvf(cell,rBEvw):
+    cell=rBEvw(cell)
    cells.append(cell)
   t.add_row(*cells)
  console.print(t)
 class ConsoleLogger(logging.Logger):
  def __init__(self,name):
-  RybEv(ConsoleLogger,self).__init__(name)
- def info(self,msg:Any,*args:Any,**kwargs:Any)->RybEw:
+  rBEvc(ConsoleLogger,self).__init__(name)
+ def info(self,msg:Any,*args:Any,**kwargs:Any)->rBEvi:
   console.print(msg%args)
- def warning(self,msg:Any,*args:Any,**kwargs:Any)->RybEw:
+ def warning(self,msg:Any,*args:Any,**kwargs:Any)->rBEvi:
   console.print("[red]Warning:[/red] ",msg%args)
- def error(self,msg:Any,*args:Any,**kwargs:Any)->RybEw:
+ def error(self,msg:Any,*args:Any,**kwargs:Any)->rBEvi:
   console.print("[red]Error:[/red] ",msg%args)
- def exception(self,msg:Any,*args:Any,**kwargs:Any)->RybEw:
+ def exception(self,msg:Any,*args:Any,**kwargs:Any)->rBEvi:
   console.print("[red]Error:[/red] ",msg%args)
   console.print_exception()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
