@@ -1,10 +1,10 @@
 import logging
-HYhXO=Exception
-HYhXi=any
-HYhXf=str
-HYhXA=None
-HYhXC=False
-HYhXv=bool
+nJtgc=Exception
+nJtgB=any
+nJtgv=str
+nJtgH=None
+nJtgT=False
+nJtga=bool
 import os
 import traceback
 from localstack import config as localstack_config
@@ -31,14 +31,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except HYhXO:
+  except nJtgc:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled("ec2"):
     local_daemon.start_in_background()
-  except HYhXO as e:
+  except nJtgc as e:
    LOG.warning("Unable to start local daemon process: %s"%e)
   if is_api_key_configured:
    if os.environ.get("EDGE_PORT")and not localstack_config.EDGE_PORT_HTTP:
@@ -53,7 +53,7 @@ def register_localstack_plugins():
    docker_flags+=["-p {a}:{p}:{p}".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols="udp"):
    docker_flags+=["-p {a}:{p}:{p}/udp".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if HYhXi([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if nJtgB([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=["-p {start}-{end}:{start}-{end}".format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled("eks"):
   kube_config=os.path.expanduser("~/.kube/config")
@@ -77,34 +77,37 @@ def load_plugin_files():
   patch_start_infra()
   aws_utils.patch_aws_utils()
   set_default_providers_to_pro()
- except HYhXO as e:
-  if "No module named" not in HYhXf(e):
+ except nJtgc as e:
+  if "No module named" not in nJtgv(e):
    print("ERROR: %s %s"%(e,traceback.format_exc()))
 def set_default_providers_to_pro():
  from localstack.services.plugins import SERVICE_PLUGINS
  pro_services=SERVICE_PLUGINS.apis_with_provider("pro")
  localstack_config.SERVICE_PROVIDER_CONFIG.bulk_set_provider_if_not_exists(pro_services,"pro")
- for service in pro_services:
+ eager_services=["azure"]
+ for service in eager_services:
+  if not is_api_enabled(service):
+   continue
   try:
    LOG.debug("loading service plugin for %s",service)
-   SERVICE_PLUGINS.get_service_container(service)
-  except HYhXO as e:
+   SERVICE_PLUGINS.get_service_container(service).start()
+  except nJtgc as e:
    LOG.error("error while loading service %s: %s",service,e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except HYhXO:
-  start_metadata_service=HYhXA
+ except nJtgc:
+  start_metadata_service=nJtgH
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except HYhXO:
+   except nJtgc:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=HYhXC
+   config_ext.ENFORCE_IAM=nJtgT
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -128,5 +131,5 @@ def _setup_logging():
  logging.getLogger("root").setLevel(logging.WARNING)
  logging.getLogger("").setLevel(logging.WARNING)
 def api_key_configured():
- return HYhXv(os.environ.get("LOCALSTACK_API_KEY"))
+ return nJtga(os.environ.get("LOCALSTACK_API_KEY"))
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
