@@ -1,11 +1,11 @@
 import json
-GUrPs=staticmethod
-GUrPf=classmethod
-GUrPt=None
-GUrPw=True
-GUrPy=hasattr
-GUrPe=Exception
-GUrPk=super
+kGfRW=staticmethod
+kGfRI=classmethod
+kGfRn=None
+kGfRP=True
+kGfRM=hasattr
+kGfRQ=Exception
+kGfRp=super
 from localstack.services.cloudformation.service_models import(REF_ARN_ATTRS,REF_ID_ATTRS,GenericBaseModel)
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone,keys_to_lower,select_attributes,to_str
@@ -13,7 +13,7 @@ from localstack_ext.services.appsync import appsync_api
 from localstack_ext.services.cloudformation.service_models import LOG
 from localstack_ext.utils.aws import aws_utils
 class AppSyncResolver(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::Resolver"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -26,40 +26,40 @@ class AppSyncResolver(GenericBaseModel):
   field_name=props.get("FieldName")
   data_source_name=props.get("DataSourceName")
   return self.fetch_details(api_id,type_name,field_name,data_source_name)
- @GUrPf
+ @kGfRI
  def fetch_details(cls,api_id,type_name,field_name,data_source_name):
   client=aws_stack.connect_to_service("appsync")
   resolvers=client.list_resolvers(apiId=api_id,typeName=type_name)["resolvers"]
   result=[r for r in resolvers if r.get("fieldName")==field_name and r.get("dataSourceName")==data_source_name]
-  return(result or[GUrPt])[0]
- @GUrPs
+  return(result or[kGfRn])[0]
+ @kGfRW
  def get_deploy_templates():
   def get_resolver_params(params,**kwargs):
    params=keys_to_lower(clone(params))
-   req_template=params.pop("requestMappingTemplateS3Location",GUrPt)
-   res_template=params.pop("responseMappingTemplateS3Location",GUrPt)
+   req_template=params.pop("requestMappingTemplateS3Location",kGfRn)
+   res_template=params.pop("responseMappingTemplateS3Location",kGfRn)
    if req_template:
-    tmpl=aws_utils.download_s3_object(req_template,as_str=GUrPw)
+    tmpl=aws_utils.download_s3_object(req_template,as_str=kGfRP)
     if tmpl:
      params["requestMappingTemplate"]=tmpl
    if res_template:
-    tmpl=aws_utils.download_s3_object(res_template,as_str=GUrPw)
+    tmpl=aws_utils.download_s3_object(res_template,as_str=kGfRP)
     if tmpl:
      params["responseMappingTemplate"]=tmpl
    return params
   return{"create":{"function":"create_resolver","parameters":get_resolver_params}}
 class GraphQLSchema(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::GraphQLSchema"
  def get_physical_resource_id(self,attribute,**kwargs):
   return "%s-GraphQLSchema"%self.props.get("ApiId")
- @GUrPf
- def fetch_details(cls,api_id,definition=GUrPt,s3_location=GUrPt):
+ @kGfRI
+ def fetch_details(cls,api_id,definition=kGfRn,s3_location=kGfRn):
   client=aws_stack.connect_to_service("appsync")
   try:
    schema=client.get_introspection_schema(apiId=api_id,format="SDL")["schema"]
-   schema=schema.read()if GUrPy(schema,"read")else schema
+   schema=schema.read()if kGfRM(schema,"read")else schema
    schema=to_str(schema)
    if schema.startswith("{"):
     schema=json.loads(schema)["schema"]
@@ -69,10 +69,10 @@ class GraphQLSchema(GenericBaseModel):
    elif s3_location:
     LOG.debug("Getting GraphQL schema definition from S3 not yet implemented")
     return{"schema":definition}
-  except GUrPe:
+  except kGfRQ:
    pass
 class AppSyncApiKey(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::ApiKey"
  def get_cfn_attribute(self,attribute_name):
@@ -81,8 +81,8 @@ class AppSyncApiKey(GenericBaseModel):
    return "key-%s"%props["ApiId"]
   if attribute_name in REF_ID_ATTRS+REF_ARN_ATTRS:
    return self.get_physical_resource_id()
-  return GUrPk(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
- def get_physical_resource_id(self,attribute=GUrPt,**kwargs):
+  return kGfRp(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=kGfRn,**kwargs):
   props=self.props
   key_id=props.get("ApiKeyId")or props.get("id")
   if not key_id or not props.get("ApiId"):
@@ -94,9 +94,9 @@ class AppSyncApiKey(GenericBaseModel):
   api_id=props.get("ApiId")
   api_id=self.resolve_refs_recursively(stack_name,api_id,resources)
   keys=client.list_api_keys(apiId=api_id).get("apiKeys",[])
-  result=[k for k in keys if k.get("description")==props.get("Description")and props.get("Expires")in[GUrPt,k.get("expires")]]
-  return(result or[GUrPt])[0]
- @GUrPf
+  result=[k for k in keys if k.get("description")==props.get("Description")and props.get("Expires")in[kGfRn,k.get("expires")]]
+  return(result or[kGfRn])[0]
+ @kGfRI
  def get_deploy_templates(cls):
   def _create_params(_,resources,resource_id,**kwargs):
    resource=cls(resources[resource_id])
@@ -108,10 +108,10 @@ class AppSyncApiKey(GenericBaseModel):
    return result
   return{"create":{"function":"create_api_key","parameters":_create_params}}
 class AppSyncDataSource(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::DataSource"
- @GUrPs
+ @kGfRW
  def get_deploy_templates():
   def lambda_get_datasource_config(params,**kwargs):
    params=keys_to_lower(clone(params))
@@ -124,8 +124,8 @@ class AppSyncDataSource(GenericBaseModel):
    return self.props.get("dataSourceArn")
   if attribute_name=="Name":
    return self.props.get("name")
-  return GUrPk(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
- def get_physical_resource_id(self,attribute=GUrPt,**kwargs):
+  return kGfRp(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=kGfRn,**kwargs):
   return self.props.get("dataSourceArn")
  def fetch_state(self,stack_name,resources):
   props=self.props
@@ -134,9 +134,9 @@ class AppSyncDataSource(GenericBaseModel):
   ds_name=self.resolve_refs_recursively(stack_name,ds_name,resources)
   api_id=self.resolve_refs_recursively(stack_name,props.get("ApiId"),resources)
   sources=client.list_data_sources(apiId=api_id)["dataSources"]
-  return([s for s in sources if s["name"]==ds_name]or[GUrPt])[0]
+  return([s for s in sources if s["name"]==ds_name]or[kGfRn])[0]
 class AppSyncFunctionConfig(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::FunctionConfiguration"
  def fetch_state(self,stack_name,resources):
@@ -146,7 +146,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
   name=self.resolve_refs_recursively(stack_name,props["Name"],resources)
   result=client.list_functions(apiId=api_id).get("functions",[])
   result=[f for f in result if f.get("name")==name]
-  return(result or[GUrPt])[0]
+  return(result or[kGfRn])[0]
  def get_cfn_attribute(self,attribute_name):
   props=self.props
   if attribute_name=="FunctionId":
@@ -157,10 +157,10 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return props.get("name")
   if attribute_name=="DataSourceName":
    return props.get("dataSourceName")
-  return GUrPk(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
+  return kGfRp(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("functionArn")
- @GUrPs
+ @kGfRW
  def get_deploy_templates():
   def func_params(params,**kwargs):
    sys_cfg=params.get("SyncConfig")
@@ -171,7 +171,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return result
   return{"create":{"function":"create_function","parameters":func_params}}
 class GraphQLAPI(GenericBaseModel):
- @GUrPs
+ @kGfRW
  def cloudformation_type():
   return "AWS::AppSync::GraphQLApi"
  def get_cfn_attribute(self,attribute_name):
@@ -179,21 +179,21 @@ class GraphQLAPI(GenericBaseModel):
   if not props.get("apiId"):
    details=self.fetch_details(props.get("Name"))
    if not details:
-    raise GUrPe('Unable to find GraphQL API named "%s"'%props.get("Name"))
+    raise kGfRQ('Unable to find GraphQL API named "%s"'%props.get("Name"))
    props["apiId"]=details["apiId"]
   if attribute_name=="ApiId":
    return props.get("apiId")
   if attribute_name in REF_ARN_ATTRS:
    return self.get_physical_resource_id(attribute_name)
   if attribute_name=="GraphQLUrl":
-   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=GUrPw)
-  return GUrPk(GraphQLAPI,self).get_cfn_attribute(attribute_name)
+   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=kGfRP)
+  return kGfRp(GraphQLAPI,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   props=self.props
   return props.get("apiId")and aws_utils.appsync_api_arn(props["apiId"])
- @GUrPf
+ @kGfRI
  def fetch_details(cls,api_name):
   client=aws_stack.connect_to_service("appsync")
   apis=client.list_graphql_apis()["graphqlApis"]
-  return([a for a in apis if a["name"]==api_name]or[GUrPt])[0]
+  return([a for a in apis if a["name"]==api_name]or[kGfRn])[0]
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
