@@ -1,36 +1,36 @@
 from localstack.services.cloudformation.deployment_utils import param_json_to_str
-JRwbB=staticmethod
-JRwbr=None
-JRwbf=classmethod
-JRwbK=str
+NeEkn=staticmethod
+NeEkI=None
+NeEkG=classmethod
+NeEkF=str
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone,select_attributes
 from localstack_ext.services.cloudformation.service_models import LOG
 class EC2VPCEndpoint(GenericBaseModel):
- @JRwbB
+ @NeEkn
  def cloudformation_type():
   return "AWS::EC2::VPCEndpoint"
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("ec2")
   result=client.describe_vpc_endpoints(Filters=[{"Name":"service-name","Values":[self.props["ServiceName"]]},{"Name":"vpc-id","Values":[self.props["VpcId"]]}])
   result=result["VpcEndpoints"]
-  return(result or[JRwbr])[0]
+  return(result or[NeEkI])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("VpcEndpointId")
- @JRwbB
+ @NeEkn
  def get_deploy_templates():
   return{"create":{"function":"create_vpc_endpoint","parameters":{"ServiceName":"ServiceName","PolicyDocument":param_json_to_str("PolicyDocument"),"VpcId":"VpcId","SecurityGroupIds":"SecurityGroupIds","SubnetIds":"SubnetIds","RouteTableIds":"RouteTableIds","VpcEndpointType":"VpcEndpointType","PrivateDnsEnabled":"PrivateDnsEnabled"}}}
 class EC2ElasticIP(GenericBaseModel):
- @JRwbB
+ @NeEkn
  def cloudformation_type():
   return "AWS::EC2::EIP"
- def get_physical_resource_id(self,attribute=JRwbr,**kwargs):
+ def get_physical_resource_id(self,attribute=NeEkI,**kwargs):
   return self.props.get("PublicIp")
  def fetch_state(self,stack_name,resources):
   if self.get_physical_resource_id():
    return self.state
- @JRwbf
+ @NeEkG
  def get_deploy_templates(cls):
   def allocate_address(resource_id,resources,resource_type,func,stack_name,*args,**kwargs):
    resource=cls(resources[resource_id])
@@ -42,7 +42,7 @@ class EC2ElasticIP(GenericBaseModel):
    return result
   return{"create":{"function":allocate_address},"delete":{"function":"release_address","parameters":["PublicIp","AllocationId"]}}
 class SubnetRouteTableAssociation(GenericBaseModel):
- @JRwbB
+ @NeEkn
  def cloudformation_type():
   return "AWS::EC2::SubnetRouteTableAssociation"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -56,7 +56,7 @@ class SubnetRouteTableAssociation(GenericBaseModel):
   tables=[t for t in tables if t["RouteTableId"]==table_id]
   if tables:
    assocs=[a for a in tables[0].get("Associations",[])if a["SubnetId"]==subnet_id]
-   return(assocs or[JRwbr])[0]
+   return(assocs or[NeEkI])[0]
  def get_deploy_templates():
   return{"create":{"function":"associate_route_table","parameters":{"RouteTableId":"RouteTableId","SubnetId":"SubnetId"}},"delete":{"function":"disassociate_route_table","parameters":{"AssociationId":"PhysicalResourceId"}}}
 class SecurityGroupInOrEgress(GenericBaseModel):
@@ -77,7 +77,7 @@ class SecurityGroupInOrEgress(GenericBaseModel):
    perms=result[0].get("IpPermissions" if self.is_ingress()else "IpPermissionsEgress")
    result=[]
    for perm in perms:
-    if JRwbK(perm["IpProtocol"])!=JRwbK(rp["IpProtocol"]):
+    if NeEkF(perm["IpProtocol"])!=NeEkF(rp["IpProtocol"]):
      continue
     if perm.get("FromPort")!=rp.get("FromPort")or perm.get("ToPort")!=rp.get("ToPort"):
      continue
@@ -87,28 +87,28 @@ class SecurityGroupInOrEgress(GenericBaseModel):
     groups=[g for g in groups if g.get("GroupId")in[src_grp_id,dst_grp_id]or g.get("GroupName")==src_grp_name]
     if groups:
      return perm
- @JRwbf
+ @NeEkG
  def is_ingress(cls):
   return "Ingress" in cls.cloudformation_type()
- @JRwbf
+ @NeEkG
  def get_deploy_templates(cls):
   def create_params(params,**kwargs):
    result=clone(params)
    source_group_name=result.get("SourceSecurityGroupName")
-   source_group_id=result.pop("SourceSecurityGroupId",JRwbr)
-   vpc_id=JRwbr
+   source_group_id=result.pop("SourceSecurityGroupId",NeEkI)
+   vpc_id=NeEkI
    if cls.is_ingress()and source_group_id and not source_group_name:
     client=aws_stack.connect_to_service("ec2")
     groups=client.describe_security_groups(GroupIds=[source_group_id])["SecurityGroups"]
-    result["SourceSecurityGroupName"]=groups and groups[0]["GroupName"]or JRwbr
-    vpc_id=groups and groups[0].get("VpcId")or JRwbr
-   dst_group_id=result.pop("DestinationSecurityGroupId",JRwbr)
+    result["SourceSecurityGroupName"]=groups and groups[0]["GroupName"]or NeEkI
+    vpc_id=groups and groups[0].get("VpcId")or NeEkI
+   dst_group_id=result.pop("DestinationSecurityGroupId",NeEkI)
    if not cls.is_ingress()and not dst_group_id:
     LOG.info("TODO: Add support for DestinationPrefixListId for %s"%cls.cloudformation_type())
    if result.get("IpProtocol"):
-    result["IpProtocol"]=JRwbK(result.get("IpProtocol"))
-   description=result.pop("Description",JRwbr)
-   cidr_ipv6=result.pop("CidrIpv6",JRwbr)
+    result["IpProtocol"]=NeEkF(result.get("IpProtocol"))
+   description=result.pop("Description",NeEkI)
+   cidr_ipv6=result.pop("CidrIpv6",NeEkI)
    if cidr_ipv6 or vpc_id:
     cidr_ip=result.get("CidrIp")
     cidr_ip=cidr_ip or("127.0.0.1/32" if description else cidr_ip)
@@ -129,11 +129,11 @@ class SecurityGroupInOrEgress(GenericBaseModel):
   func_name=("authorize_security_group_ingress" if cls.is_ingress()else "authorize_security_group_egress")
   return{"create":{"function":func_name,"parameters":create_params}}
 class SecurityGroupEgress(SecurityGroupInOrEgress):
- @JRwbB
+ @NeEkn
  def cloudformation_type():
   return "AWS::EC2::SecurityGroupEgress"
 class SecurityGroupIngress(SecurityGroupInOrEgress):
- @JRwbB
+ @NeEkn
  def cloudformation_type():
   return "AWS::EC2::SecurityGroupIngress"
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
