@@ -1,11 +1,11 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-zPSUR=staticmethod
-zPSUJ=None
-zPSUH=False
+efHUw=staticmethod
+efHUK=None
+efHUD=False
 from localstack.utils.aws import aws_stack
 from localstack_ext.utils.aws import aws_utils
 class ECRRepository(GenericBaseModel):
- @zPSUR
+ @efHUw
  def cloudformation_type():
   return "AWS::ECR::Repository"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -20,13 +20,13 @@ class ECRRepository(GenericBaseModel):
   registry_id=props.get("LifecyclePolicy",{}).get("RegistryId")
   kwargs={"registryId":registry_id}if registry_id else{}
   result=client.describe_repositories(repositoryNames=[repo_name],**kwargs).get("repositories",[])
-  return(result or[zPSUJ])[0]
- @zPSUR
+  return(result or[efHUK])[0]
+ @efHUw
  def get_deploy_templates():
   def _create_params(params,**kwargs):
    encryption_type=params.get("EncryptionConfiguration",{}).get("EncryptionType","AES-256")
-   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",zPSUH)},"encryptionConfiguration":{"encryptionType":encryption_type}}
-   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not zPSUJ):
+   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",efHUD)},"encryptionConfiguration":{"encryptionType":encryption_type}}
+   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not efHUK):
     response["encryptionConfiguration"]["kmsKey"]=params["EncryptionConfiguration"]["KmsKey"]
    return response
   result={"create":{"function":"create_repository","parameters":_create_params},"delete":{"function":"delete_repository","parameters":{"repositoryName":"RepositoryName"}}}
