@@ -1,8 +1,8 @@
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
-AnCTd=staticmethod
-AnCTj=super
+PSGIO=staticmethod
+PSGIh=super
 class KinesisAnalyticsApplicationOutput(GenericBaseModel):
- @AnCTd
+ @PSGIO
  def cloudformation_type():
   return "AWS::KinesisAnalytics::ApplicationOutput"
  def get_cfn_attribute(self,attribute_name):
@@ -11,9 +11,9 @@ class KinesisAnalyticsApplicationOutput(GenericBaseModel):
    output_name=self.props.get("Output",{}).get("Name")
    if app_name and output_name:
     return "%s!%s"%(app_name,output_name)
-  return AnCTj(KinesisAnalyticsApplicationOutput,self).get_cfn_attribute(attribute_name)
+  return PSGIh(KinesisAnalyticsApplicationOutput,self).get_cfn_attribute(attribute_name)
 class KinesisAnalyticsApplication(GenericBaseModel):
- @AnCTd
+ @PSGIO
  def cloudformation_type():
   return "AWS::KinesisAnalytics::Application"
  def get_cfn_attribute(self,attribute_name):
@@ -21,5 +21,5 @@ class KinesisAnalyticsApplication(GenericBaseModel):
    app_name=self.props.get("ApplicationName")
    if app_name:
     return app_name
-  return AnCTj(KinesisAnalyticsApplication,self).get_cfn_attribute(attribute_name)
+  return PSGIh(KinesisAnalyticsApplication,self).get_cfn_attribute(attribute_name)
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
