@@ -1,29 +1,30 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-CmSiw=staticmethod
-CmSia=None
-CmSiY=classmethod
+hGpmB=staticmethod
+hGpme=None
+hGpmb=classmethod
 from localstack.utils.aws import aws_stack
+from localstack.utils.common import clone
 class KafkaCluster(GenericBaseModel):
- @CmSiw
+ @hGpmB
  def cloudformation_type():
   return "AWS::MSK::Cluster"
- def get_physical_resource_id(self,attribute=CmSia,**kwargs):
+ def get_physical_resource_id(self,attribute=hGpme,**kwargs):
   return self.props.get("ClusterArn")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("kafka")
   cluster_name=self.resolve_refs_recursively(stack_name,self.props["ClusterName"],resources)
   clusters=client.list_clusters()["ClusterInfoList"]
   clusters=[c for c in clusters if c["ClusterName"]==cluster_name]
-  return(clusters or[CmSia])[0]
- @CmSiY
+  return(clusters or[hGpme])[0]
+ @hGpmb
  def get_deploy_templates(cls):
   def _create_params(params,resource_id,resources,**kwargs):
    resource=cls(resources[resource_id])
-   props=resource.props
+   props=clone(resource.props)
    storage_info=props.get("BrokerNodeGroupInfo",{}).get("StorageInfo",{})
    if "EBSStorageInfo" in storage_info:
     storage_info["EbsStorageInfo"]=storage_info.pop("EBSStorageInfo")
-   return{"ClusterArn":resource.props.get("ClusterArn")}
+   return props
   def _delete_params(params,resource_id,resources,**kwargs):
    resource=cls(resources[resource_id])
    return{"ClusterArn":resource.props.get("ClusterArn")}
