@@ -1,16 +1,16 @@
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
-CmQrE=str
-CmQrI=staticmethod
-CmQrF=None
-CmQrB=super
+YWAFw=str
+YWAFL=staticmethod
+YWAFe=None
+YWAFJ=super
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import select_attributes,short_uid
-def canonicalize_name(name:CmQrE)->CmQrE:
+def canonicalize_name(name:YWAFw)->YWAFw:
  if name[-1]!=".":
   return f"{name}."
  return name
 class Route53HostedZone(GenericBaseModel):
- @CmQrI
+ @YWAFL
  def cloudformation_type():
   return "AWS::Route53::HostedZone"
  def fetch_state(self,stack_name,resources):
@@ -18,16 +18,16 @@ class Route53HostedZone(GenericBaseModel):
   result=client.list_hosted_zones()["HostedZones"]
   canonical_name=canonicalize_name(self.props.get("Name"))
   result=[z for z in result if z["Name"]==canonical_name]
-  return(result or[CmQrF])[0]
- def get_physical_resource_id(self,attribute=CmQrF,**kwargs):
+  return(result or[YWAFe])[0]
+ def get_physical_resource_id(self,attribute=YWAFe,**kwargs):
   return self.props.get("Id")
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="NameServers":
    return[self.props.get("Name")]
   if attribute_name in REF_ID_ATTRS:
    return self.get_physical_resource_id()
-  return CmQrB(Route53HostedZone,self).get_cfn_attribute(attribute_name)
- @CmQrI
+  return YWAFJ(Route53HostedZone,self).get_cfn_attribute(attribute_name)
+ @YWAFL
  def get_deploy_templates():
   def _get_params(resource_props,resources,resource_id,*args,**kwargs):
    resource=Route53HostedZone(resources[resource_id])
